--
-- ArticulatedSteering
-- Specialization for ArticulatedSteering1
--
-- SFM-Modding
-- @author  Manuel Leithner
-- @date  28/04/10
--

ArticulatedSteering1 = {};

function ArticulatedSteering1.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Steerable, specializations) and SpecializationUtil.hasSpecialization(AITractor, specializations);
end;

function ArticulatedSteering1:load(xmlFile)
	
	self.articulatedSteering1 = {};	
	self.articulatedSteering1.joint = getXMLInt(xmlFile, "vehicle.articulatedSteering1#joint");
	if self.articulatedSteering1.joint ~= nil then
		self.articulatedSteering1.minRot = Utils.degToRad(getXMLFloat(xmlFile, "vehicle.articulatedSteering1#minRot"));
		self.articulatedSteering1.maxRot = Utils.degToRad(getXMLFloat(xmlFile, "vehicle.articulatedSteering1#maxRot"));
		self.articulatedSteering1.rotSpeed = Utils.degToRad(Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.articulatedSteering1#rotSpeed"),40));
		self.articulatedSteering1.curRot = 0;
		
		local maxRotTime = self.articulatedSteering1.maxRot / self.articulatedSteering1.rotSpeed;
		local minRotTime = self.articulatedSteering1.minRot / self.articulatedSteering1.rotSpeed;
		if minRotTime > maxRotTime then
			local temp = minRotTime;
			minRotTime = maxRotTime;
			maxRotTime = temp;
		end;

		self.maxRotTime = math.max(maxRotTime, self.maxRotTime);
		self.minRotTime = math.min(minRotTime, self.minRotTime);
		
		self.frameRotateTime = 0;
		self.doOnce = true;
		self.turningInProcess = false;
		self.aiBackUp = self.aiTractorDirectionNode;
	else
		print("Could not load articulated steering. Joint is nil");
	end;
end;

function ArticulatedSteering1:delete()
end;

function ArticulatedSteering1:mouseEvent(posX, posY, isDown, isUp, button)
end;

function ArticulatedSteering1:keyEvent(unicode, sym, modifier, isDown)
end;

function ArticulatedSteering1:update(dt)

    if self:getIsActive() then
		if self.articulatedSteering1.joint ~= nil then
			local steeringAngle = self.rotatedTime * self.articulatedSteering1.rotSpeed;
			steeringAngle = math.max(math.min(steeringAngle, self.articulatedSteering1.maxRot), self.articulatedSteering1.minRot);
			local jointNode = self.componentJoints[self.articulatedSteering1.joint].jointNode;
			local jointIndex = self.componentJoints[self.articulatedSteering1.joint].jointIndex;
			setRotation(jointNode, 0, steeringAngle, 0);
			setJointFrame(jointIndex, 1, jointNode);
			self.articulatedSteering1.curRot = steeringAngle;
			
			-- Turning Bug-Fix
			if self.turnStage ~= 0 and self.doOnce then	
				self.aiTractorDirectionNode = self.components[2].node;
				self.frameRotateTime = 100;
				self.turningInProcess = true;
				self.doOnce = false;
			end;			
			if self.turnStage == 0 and self.turningInProcess then
				self.frameRotateTime = self.frameRotateTime - dt;
			end;				
			if self.frameRotateTime <= 0 then
				self.doOnce = true;
				self.turningInProcess = false;
				self.aiTractorDirectionNode = self.aiBackUp;
				-- Fix excalating steering in helping modus
				setRotation(self.aiTractorDirectionNode, 0, -steeringAngle/2, 0);
			end;
		end;
    end;
end;

function ArticulatedSteering1:draw()
end;
